@@ -22,9 +22,9 @@ from email.utils import unquote
 
 import requests
 import html2text
-import youtube_dl
+import yt_dlp
 
-from youtube_dl.utils import format_bytes, timeconvert
+from yt_dlp.utils import format_bytes, timeconvert
 from requests.exceptions import InvalidSchema, InvalidURL, MissingSchema, RequestException
 
 from moodle_dl.state_recorder.file import File
@@ -305,6 +305,12 @@ class URLTarget(object):
             self.thread_report[self.thread_id]['percentage'] = 100
             self.thread_report[self.thread_id]['extra_totalsize'] = None
 
+    def yt_hook_after_move(self, final_filename: str):
+        rel_pos = final_filename.find(self.destination)
+        if rel_pos >= 0:
+            final_filename = final_filename[rel_pos:]
+        self.file.saved_to = final_filename
+
     def is_blocked_for_youtube_dl(self, url_to_download: str):
         url_parsed = urlparse.urlparse(url_to_download)
         if url_parsed.hostname.endswith('youtube.com') and url_parsed.path.startswith('/channel/'):
@@ -438,7 +444,7 @@ class URLTarget(object):
         external_file_downloader = external_file_downloaders.get(url_parsed.netloc, "")
         if isHTML and external_file_downloader != "":
             # This link is to be downloaded from an external program.
-            cmd = external_file_downloader.replace('%U', url_to_download)
+            cmd = external_file_downloader.replace('%U', self.file.content_fileurl)
             logging.debug(
                 'T%s - Run external downloader using the following command: `%s`',
                 self.thread_id,
@@ -501,6 +507,7 @@ class URLTarget(object):
             ydl_opts = {
                 'logger': self.YtLogger(self),
                 'progress_hooks': [self.yt_hook],
+                'post_hooks': [self.yt_hook_after_move],
                 'outtmpl': outtmpl,
                 'nocheckcertificate': self.skip_cert_verify,
                 'retries': 10,
@@ -515,7 +522,7 @@ class URLTarget(object):
             if cookies_path is not None and os.path.isfile(cookies_path):
                 ydl_opts.update({'cookiefile': cookies_path})
 
-            ydl = youtube_dl.YoutubeDL(ydl_opts)
+            ydl = yt_dlp.YoutubeDL(ydl_opts)
             add_additional_extractors(ydl)
 
             videopasswords = self.options.get('videopasswords', {})
@@ -536,7 +543,8 @@ class URLTarget(object):
                     if ydl_results == 1:
                         pass
                     elif self.file.module_name != 'index_mod-page':
-                        self.file.saved_to = str(Path(self.destination) / self.filename)
+                        # we now set the saved_to path in yt_hook_after_move
+                        # self.file.saved_to = str(Path(self.destination) / self.filename)
                         self.file.time_stamp = int(time.time())
 
                         self.success = True
@@ -676,19 +684,18 @@ class URLTarget(object):
         if self.file.content_type == 'description' and not ignore_attributes:
             self.file.saved_to = str(Path(self.destination) / (self.filename + '.md'))
 
-            self.file.saved_to = self._rename_if_exists(self.file.saved_to)
+        elif self.file.content_type == 'html' and not ignore_attributes:
+            self.file.saved_to = str(Path(self.destination) / (self.filename + '.html'))
 
         elif self.file.module_modname.startswith('url') and not ignore_attributes:
             self.file.saved_to = str(Path(self.destination) / (self.filename + '.desktop'))
             if os.name == 'nt' or platform.system() == "Darwin":
                 self.file.saved_to = str(Path(self.destination) / (self.filename + '.URL'))
 
-            self.file.saved_to = self._rename_if_exists(self.file.saved_to)
-
         else:  # normal path
             self.file.saved_to = str(Path(self.destination) / self.filename)
 
-            self.file.saved_to = self._rename_if_exists(self.file.saved_to)
+        self.file.saved_to = self._rename_if_exists(self.file.saved_to)
 
     def create_description(self):
         """
