@@ -7,7 +7,7 @@ from getpass import getpass
 from urllib.parse import urlparse
 from distutils.version import StrictVersion
 
-from youtube_dl.utils import determine_ext
+from yt_dlp.utils import determine_ext
 
 from moodle_dl.utils import cutie
 from moodle_dl.utils.logger import Log
@@ -20,6 +20,7 @@ from moodle_dl.moodle_connector.cookie_handler import CookieHandler
 from moodle_dl.moodle_connector.results_handler import ResultsHandler
 from moodle_dl.moodle_connector.pages_handler import PagesHandler
 from moodle_dl.moodle_connector.forums_handler import ForumsHandler
+from moodle_dl.moodle_connector.folders_handler import FoldersHandler
 from moodle_dl.moodle_connector.quizzes_handler import QuizzesHandler
 from moodle_dl.moodle_connector.lessons_handler import LessonsHandler
 from moodle_dl.moodle_connector.workshops_handler import WorkshopsHandler
@@ -158,20 +159,26 @@ class MoodleService:
         if use_http:
             scheme = 'http://'
 
-        version = RequestHelper(
-            moodle_domain,
-            moodle_path,
-            skip_cert_verify=self.skip_cert_verify,
-            use_http=use_http,
-        ).get_simple_moodle_version()
+        atomatic_procedure_warning = (
+            'Between version 3.81 and 3.82 a change was added to'
+            + ' Moodle so that automatic copying of the SSO token'
+            + ' might not work.'
+        )
+        try:
+            version = RequestHelper(
+                moodle_domain,
+                moodle_path,
+                skip_cert_verify=self.skip_cert_verify,
+                use_http=use_http,
+            ).get_simple_moodle_version()
 
-        if StrictVersion(version) > StrictVersion("3.8.1"):
+            if StrictVersion(version) > StrictVersion("3.8.1"):
+                Log.warning(atomatic_procedure_warning + '\nYou can still try it, your version is: ' + str(version))
+
+        except ConnectionError:
             Log.warning(
-                'Between version 3.81 and 3.82 a change was added to'
-                + ' Moodle so that automatic copying of the SSO token'
-                + ' might not work.'
-                + '\nYou can still try it, your version is: '
-                + str(version)
+                atomatic_procedure_warning
+                + '\nThe version of your Moodle could not be detected, you can still try the automatic procedure.'
             )
 
         print(' If you want to copy the login-token manual, you will be guided through the manual copy process.')
@@ -288,6 +295,8 @@ class MoodleService:
         lessons_handler = LessonsHandler(request_helper, version)
         workshops_handler = WorkshopsHandler(request_helper, version)
         pages_handler = PagesHandler(request_helper, version)
+        folders_handler = FoldersHandler(request_helper, version)
+
         results_handler.setVersion(version)
 
         if download_also_with_cookie:
@@ -333,6 +342,9 @@ class MoodleService:
 
         pages = pages_handler.fetch_pages(courses)
 
+        folders = folders_handler.fetch_folders(courses)
+
+        courses = self.add_options_to_courses(courses)
         index = 0
         for course in courses:
             index += 1
@@ -361,9 +373,10 @@ class MoodleService:
                 'lesson': lessons.get(course.id, {}),
                 'workshop': workshops.get(course.id, {}),
                 'page': pages.get(course.id, {}),
+                'folder': folders.get(course.id, {}),
             }
             results_handler.set_fetch_addons(course_fetch_addons)
-            course.files = results_handler.fetch_files(course.id)
+            course.files = results_handler.fetch_files(course)
 
             filtered_courses.append(course)
         print('')
@@ -372,9 +385,8 @@ class MoodleService:
         changes = self.recorder.changes_of_new_version(filtered_courses)
 
         # Filter changes
-        changes = self.filter_courses(changes, self.config_helper, cookie_handler, courses_list + public_courses_list)
-
         changes = self.add_options_to_courses(changes)
+        changes = self.filter_courses(changes, self.config_helper, cookie_handler, courses_list + public_courses_list)
 
         return changes
 
@@ -388,6 +400,7 @@ class MoodleService:
             if options is not None:
                 course.overwrite_name_with = options.get('overwrite_name_with', None)
                 course.create_directory_structure = options.get('create_directory_structure', True)
+                course.excluded_sections = options.get("excluded_sections", [])
 
         return courses
 
@@ -449,8 +462,12 @@ class MoodleService:
                 if (
                     # Filter Assignment Submission Files
                     (download_submissions or (not (file.module_modname.endswith('assign') and file.deleted)))
-                    # Filter Description Files
-                    and (download_descriptions or file.content_type != 'description')
+                    # Filter Description Files (except the forum posts)
+                    and (
+                        download_descriptions
+                        or file.content_type != 'description'
+                        or (file.module_modname == 'forum' and file.content_type == 'description')
+                    )
                     # Filter Database Files
                     and (download_databases or file.content_type != 'database_file')
                     # Filter Quiz Files
@@ -463,6 +480,8 @@ class MoodleService:
                     and (download_also_with_cookie or (not file.module_modname.startswith('cookie_mod-')))
                     # Exclude files whose file extension is blacklisted
                     and (not (determine_ext(file.content_filename) in exclude_file_extensions))
+                    # Exclude files that are in excluded sections
+                    and (ResultsHandler.should_download_section(file.section_id, course.excluded_sections))
                 ):
                     course_files.append(file)
             course.files = course_files
