@@ -1,3 +1,7 @@
+import re
+
+import html2text
+
 from moodle_dl.state_recorder.course import Course
 from moodle_dl.download_service.url_target import URLTarget
 
@@ -17,13 +21,21 @@ class TelegramFormater:
             str: The new message
         """
         # Replace Telegram Entities
-        new_line = new_line.replace('<', '&lt;').replace('>', '&gt')
+        new_line = re.sub("<(?!/b>|b>)", '&lt;', new_line)
+        new_line = re.sub("(?<!</b)(?<!<b)>", '&gt;', new_line)
         if len(one_msg_content) + len(new_line) >= 4096:
             msg_list.append(one_msg_content)
             return new_line
         else:
             return one_msg_content + new_line
 
+    @classmethod
+    def make_bold(cls, string: str) -> str:
+        """
+        Makes a string bold in a telegram message
+        """
+        return '<b>' + string + '</b>'
+
     @classmethod
     def create_full_moodle_diff_messages(cls, changed_courses: [Course]) -> [str]:
         """
@@ -42,7 +54,7 @@ class TelegramFormater:
         one_msg_content = '%s new Changes in the Moodle courses!' % (diff_count)
 
         for course in changed_courses:
-            new_line = '\r\n\r\n\r\n👉 **' + course.fullname + '**\r\n'
+            new_line = '\r\n\r\n\r\n👉 ' + cls.make_bold(course.fullname) + '\r\n'
             one_msg_content = cls.append_with_limit(new_line, one_msg_content, result_list)
 
             for file in course.files:
@@ -60,16 +72,28 @@ class TelegramFormater:
 
                 one_msg_content = cls.append_with_limit(new_line, one_msg_content, result_list)
 
-                if file.content_type == 'description':
+                if (not file.moved and not file.deleted) and (
+                    file.content_type == 'description'
+                    or (file.content_type == 'html' and file.module_modname == 'page')
+                ):
+                    text_lines = []
                     try:
-                        with open(saved_to_path, 'r', encoding='utf-8') as description_file:
-                            description_lines = description_file.read().splitlines()
-                    except Exception:
-                        description_lines = []
+                        with open(saved_to_path, 'r', encoding='utf-8') as content_file:
+                            content = content_file.read()
 
-                    if len(description_lines) > 0:
+                            if file.content_type == 'html':
+                                h2t_handler = html2text.HTML2Text()
+                                content = h2t_handler.handle(content).strip()
+                                if content == '':
+                                    continue
+
+                            text_lines = content.splitlines()
+                    except Exception:
+                        text_lines = []
+
+                    if len(text_lines) > 0:
                         one_msg_content = cls.append_with_limit('\r\n👇\r\n', one_msg_content, result_list)
-                        for new_line in description_lines:
+                        for new_line in text_lines:
                             new_line = new_line + '\r\n'
                             one_msg_content = cls.append_with_limit(new_line, one_msg_content, result_list)
                         one_msg_content = cls.append_with_limit('👆\r\n', one_msg_content, result_list)
