@@ -9,11 +9,7 @@ from moodle_dl.state_recorder.course import Course
 from moodle_dl.download_service.url_target import URLTarget
 from moodle_dl.notification_services.xmpp.xmpp_shooter import XmppShooter
 from moodle_dl.notification_services.notification_service import NotificationService
-from moodle_dl.notification_services.telegram.telegram_formater import (
-    create_full_moodle_diff_messages,
-    create_full_error_messages,
-    create_full_failed_downloads_messages,
-)
+from moodle_dl.notification_services.xmpp.xmpp_formater import XmppFormater as XF
 
 
 class XmppService(NotificationService):
@@ -102,7 +98,7 @@ class XmppService(NotificationService):
         if not self._is_configured():
             return
 
-        messages = create_full_moodle_diff_messages(changes)
+        messages = XF.create_full_moodle_diff_messages(changes)
 
         self._send_messages(messages)
 
@@ -118,7 +114,7 @@ class XmppService(NotificationService):
 
         if not xmpp_cfg.get('send_error_msg', True):
             return
-        messages = create_full_error_messages(error_description)
+        messages = XF.create_full_error_messages(error_description)
 
         self._send_messages(messages)
 
@@ -134,6 +130,6 @@ class XmppService(NotificationService):
 
         if not xmpp_cfg.get('send_error_msg', True):
             return
-        messages = create_full_failed_downloads_messages(failed_downloads)
+        messages = XF.create_full_failed_downloads_messages(failed_downloads)
 
         self._send_messages(messages)
