@@ -1,14 +1,14 @@
 import re
 
-from youtube_dl.extractor.common import InfoExtractor
+from yt_dlp.extractor.common import InfoExtractor
 
-from youtube_dl.compat import (
+from yt_dlp.compat import (
     compat_urllib_parse,
     compat_urllib_parse_urlparse,
     compat_urllib_parse_unquote,
 )
 
-from youtube_dl.utils import (
+from yt_dlp.utils import (
     ExtractorError,
     int_or_none,
     url_or_none,
@@ -21,7 +21,7 @@ from youtube_dl.utils import (
 )
 
 
-class Owncloud(InfoExtractor):
+class OwncloudIE(InfoExtractor):
     IE_NAME = 'owncloud'
     _INSTANCES_RE = r'''(?:
                             .*\.?sciebo\.de|
